@@ -1,3 +1,3 @@
 # Basic Exception to handle not found companies
-class CompanySnapshotNotFound(Exception):
+class CompanySnapshotNotFoundException(Exception):
     pass
